<td
    ng-click='removerow(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'>{{row.box}}</td>
<td
    ng-click='removerow(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'>{{row.quantity}}</td>
<td
    ng-click='removerow(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'>{{row.product_final}}</td>
<td
    ng-click='removerow(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'>
    <script type="text/ng-template" id="crew"></script>
    <span ng-show='row.product_unique'>{{row.product_unique|nicenull}}</span>
    <span ng-hide='row.product_unique'>{{row.product_unique_value|nicenull}}</span>
</td>
<td
    ng-click='removerow(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'>{{row.caducity|nicenull}}</td>
<td
    ng-click='setlinenotes(row.pk)'>
    <center>
        <span
            class='fa'
            ng-if="!row.virtual"
            popover-placement="left"
            uib-popover="{{row.notes}}"
            popover-trigger="mouseenter"
            ng-class="{'text-warning': row.notes || row.total_notes, 'text-success': !row.notes && !row.total_notes, 'fa-exclamation-triangle': row.notes || row.total_notes, 'fa-check': !row.notes && !row.total_notes}"></span>
        <span ng-if='row.total_notes'>{{row.total_notes}}</span>
    </center>
</td>
