<td
    ng-class="{'bg-info': row.virtual, 'bg-danger': !row.virtual && !row.purchasesorder, 'bg-success': !row.virtual && row.missing}">
    <span ng-if='!row.virtual' codenerix-html-compile="data.meta.context.form_order_row"></span>
</td>
<td
    ng-click='removerecord(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'
    ng-class="{'bg-info': row.virtual, 'bg-danger': !row.virtual && !row.purchasesorder, 'bg-success': !row.virtual && row.missing}">{{row.box}}</td>
<td
    ng-click='removerecord(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'
    ng-class="{'bg-info': row.virtual, 'bg-danger': !row.virtual && !row.purchasesorder, 'bg-success': !row.virtual && row.missing}">{{row.quantity}}<span ng-if='row.missing' class='text-success'><b> (+{{row.missing}})</b></span></td>
<td
    ng-click='removerecord(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'
    ng-class="{'bg-info': row.virtual, 'bg-danger': !row.virtual && !row.purchasesorder, 'bg-success': !row.virtual && row.missing}">{{row.product_final}}</td>
<td
    ng-click='removerecord(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'
    ng-class="{'bg-info': row.virtual, 'bg-danger': !row.virtual && !row.purchasesorder, 'bg-success': !row.virtual && row.missing}">
    <span>{{row.product_unique_value|codenerix}}</span>
</td>
<td
    ng-click='removerecord(row.pk, data.meta.gentranslate.removerecord, {"name": row.product_final+": "+(row.product_unique || row.product_unique_value)})'
    ng-class="{'bg-info': row.virtual, 'bg-danger': !row.virtual && !row.purchasesorder, 'bg-success': !row.virtual && row.missing}">{{row.caducity}}</td>
<td
    ng-click='setlinenotes(row.pk)'
    ng-class="{'bg-info': row.virtual, 'bg-danger': !row.virtual && !row.purchasesorder, 'bg-success': !row.virtual && row.missing}">
    <center>
        <span
            class='fa'
            ng-if="!row.virtual"
            popover-placement="left" uib-popover="{{row.notes}}" popover-trigger="mouseenter"
            ng-class="{'text-warning': row.notes, 'text-success': !row.notes, 'fa-exclamation-triangle': row.notes, 'fa-check': !row.notes, 'fa-edit': row.notes}"></span>
    </center>
</td>
