<td
    class="text-center"
    ng-class="{'bg-warning':row.processed=='False'}"
    ng-click="$event.stopPropagation()"
    ng-show="data.table.head.extra_fields.field_check!=None">
       <input type="checkbox" name="checkline" value="{{ row.pk }}" ng-checked="CDNX_checkline_head" ng-model="CDNX_checkline[row.pk]" />
</td>
<td
    ng-class="{'bg-warning':row.processed=='False'}"
    ng-click="gotourl(data.meta.context.url_doinventory.replace('__IPK__', row.pk)); $event.stopPropagation()">{{row.storage|codenerix}}</td>
<td
    ng-class="{'bg-warning':row.processed=='False'}"
    ng-click="gotourl(data.meta.context.url_doinventory.replace('__IPK__', row.pk)); $event.stopPropagation()">{{row.zone|codenerix}}</td>
<td
    ng-class="{'bg-warning':row.processed=='False'}"
    ng-click="gotourl(data.meta.context.url_doinventory.replace('__IPK__', row.pk)); $event.stopPropagation()">{{row.created|codenerix}}</td>
<td
    ng-class="{'bg-warning':row.processed=='False'}"
    ng-click="gotourl(data.meta.context.url_doinventory.replace('__IPK__', row.pk)); $event.stopPropagation()">
    <span ng-if="row.end">{{row.end|codenerix}}</span>
    <span ng-if="!row.end">-</span>
</td>
<td
    ng-class="{'bg-warning':row.processed=='False'}"
    ng-click="gotourl(data.meta.context.url_doinventory.replace('__IPK__', row.pk)); $event.stopPropagation()">{{row.noets|codenerix}}</td>
<td
    ng-class="{'bg-warning':row.processed=='False'}">
    <a
        ng-href="{{data.meta.context.url_getreport.replace('__IPK__', row.pk)}}"
        ng-click="$event.stopPropagation()"
        class="btn btn-sm status btn-default ng-binding ng-scope">{{data.meta.gentranslate.getreport}}</a>
    <button
        ng-href="{{data.meta.context.url_getreport.replace('__IPK__', row.pk)}}"
        class="btn btn-sm status btn-default ng-binding ng-scope">{{data.meta.gentranslate.Edit}}</button>
</td>
<td
    ng-class="{'bg-warning':row.processed=='False'}"
    class="text-center" ng-click="$event.stopPropagation()" ng-show="data.table.head.extra_fields.field_delete">
        <i ng-click="removerecord(row.pk, 'Delete items?');$event.stopPropagation()" class="glyphicon glyphicon-trash pointer"></i>
</td>
