<td class="text-center" ng-click="$event.stopPropagation()" ng-show="data.table.head.extra_fields.field_check!=None">
       <input type="checkbox" name="checkline" value="{{ row.pk }}" ng-checked="CDNX_checkline_head" ng-model="CDNX_checkline[row.pk]" />
</td>

<td ng-click="gotourl(data.meta.context.url_dooutgoingalbaran.replace('__IPK__', row.pk)); $event.stopPropagation()">{{row.request_stock|codenerix}}</td>
<td ng-click="gotourl(data.meta.context.url_dooutgoingalbaran.replace('__IPK__', row.pk)); $event.stopPropagation()">{{row.prepare_user|codenerix}}</td>
<td ng-click="gotourl(data.meta.context.url_dooutgoingalbaran.replace('__IPK__', row.pk)); $event.stopPropagation()">{{row.prepare_date|codenerix}}</td>
<td ng-click="gotourl(data.meta.context.url_dooutgoingalbaran.replace('__IPK__', row.pk)); $event.stopPropagation()">{{row.outgoing_date|codenerix}}</td>
<td ng-click="gotourl(data.meta.context.url_dooutgoingalbaran.replace('__IPK__', row.pk)); $event.stopPropagation()">{{row.estimated_date|codenerix}}</td>

<td class="text-center" ng-click="$event.stopPropagation()" ng-show="data.table.head.extra_fields.field_delete">
        <i ng-click="removerecord(row.pk, 'Delete items?');$event.stopPropagation()" class="glyphicon glyphicon-trash pointer"></i>
</td>
