# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-04-26 08:34
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_storages', '0023_auto_20180414_1252'),
    ]

    operations = [
        migrations.AddField(
            model_name='inventory',
            name='storage',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='inventorys', to='codenerix_storages.Storage', verbose_name='Storage'),
        ),
        migrations.AddField(
            model_name='inventory',
            name='zone',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='inventorys', to='codenerix_storages.StorageZone', verbose_name='Zone'),
        ),
    ]
