# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-19 09:34
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_storages', '0008_auto_20180119_1029'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='inventory',
            name='closed',
        ),
        migrations.RemoveField(
            model_name='inventory',
            name='opened',
        ),
        migrations.AddField(
            model_name='inventory',
            name='end',
            field=models.DateTimeField(blank=True, null=True, verbose_name='End'),
        ),
        migrations.AddField(
            model_name='inventory',
            name='start',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Start'),
        ),
    ]
