# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-04-30 17:09
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_storages', '0025_auto_20180426_1035'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='lineoutgoingalbaran',
            name='prepare_user',
        ),
        migrations.AddField(
            model_name='outgoingalbaran',
            name='inventory',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='outgoing_albarans', to='codenerix_storages.InventoryOut', verbose_name='Inventory'),
        ),
        migrations.AlterField(
            model_name='outgoingalbaran',
            name='request_stock',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='outgoing_albarans', to='codenerix_storages.RequestStock', verbose_name='Request stock'),
        ),
    ]
