# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-19 11:29
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_storages', '0014_inventoryinline_purchasesorder'),
    ]

    operations = [
        migrations.AlterField(
            model_name='inventoryinline',
            name='purchasesorder',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='inventory_lines', to='codenerix_invoicing.PurchasesOrder', verbose_name='Inventory line'),
        ),
    ]
