# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-18 17:03
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_storages', '0006_auto_20180118_1724'),
    ]

    operations = [
        migrations.RenameField(
            model_name='inventoryalbaran',
            old_name='storage_operator',
            new_name='operator',
        ),
    ]
