# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-07-08 05:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_storages', '0029_auto_20180430_1924'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lineoutgoingalbaran',
            name='product_unique',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='line_outgoing_albarans', to='codenerix_products.ProductUnique', verbose_name='Product Unique'),
        ),
    ]
