# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-18 09:40
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_storages', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='storageboxkind',
            name='max_weight',
            field=models.FloatField(blank=True, null=True, verbose_name='Max weight'),
        ),
    ]
