# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-19 09:29
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_products', '0006_auto_20180118_1126'),
        ('codenerix_storages', '0007_auto_20180118_1803'),
    ]

    operations = [
        migrations.CreateModel(
            name='InventoryLine',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('quantity', models.FloatField(default=1.0, verbose_name='Quantity')),
                ('box', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='storage_inventorys', to='codenerix_storages.StorageBox', verbose_name='Box')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.RemoveField(
            model_name='inventoryalbaran',
            name='inventory',
        ),
        migrations.RemoveField(
            model_name='inventoryalbaran',
            name='operator',
        ),
        migrations.RemoveField(
            model_name='inventoryalbaranline',
            name='inventory_albaran',
        ),
        migrations.RemoveField(
            model_name='inventoryalbaranline',
            name='product_unique',
        ),
        migrations.AlterField(
            model_name='inventory',
            name='closed',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Date'),
        ),
        migrations.AlterField(
            model_name='inventory',
            name='opened',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Date'),
        ),
        migrations.DeleteModel(
            name='InventoryAlbaran',
        ),
        migrations.DeleteModel(
            name='InventoryAlbaranLine',
        ),
        migrations.AddField(
            model_name='inventoryline',
            name='inventory',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='storage_inventorys', to='codenerix_storages.Inventory', verbose_name='Inventory'),
        ),
        migrations.AddField(
            model_name='inventoryline',
            name='operator',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='storage_inventorys', to='codenerix_storages.StorageOperator', verbose_name='Storage Operator'),
        ),
        migrations.AddField(
            model_name='inventoryline',
            name='product_final',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='storage_inventorylines', to='codenerix_products.ProductFinal', verbose_name='Product Final'),
        ),
        migrations.AddField(
            model_name='inventoryline',
            name='product_unique',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='storage_inventorylines', to='codenerix_products.ProductUnique', verbose_name='Product Unique'),
        ),
    ]
