# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-27 07:58
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0014_auto_20180227_0858'),
        ('codenerix_storages', '0017_inventoryoutline_caducity'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='inventoryoutline',
            name='caducity',
        ),
        migrations.AddField(
            model_name='inventoryinline',
            name='purchaseslinealbaran',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='inventory_lines', to='codenerix_invoicing.PurchasesLineAlbaran', verbose_name='Line Albaran'),
        ),
        migrations.AlterField(
            model_name='inventoryinline',
            name='inventory',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='inventory_lines', to='codenerix_storages.InventoryIn', verbose_name='Inventory'),
        ),
        migrations.AlterField(
            model_name='inventoryinline',
            name='purchasesorder',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='inventory_lines', to='codenerix_invoicing.PurchasesOrder', verbose_name='Order'),
        ),
    ]
