# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-01-23 12:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_storages', '0009_auto_20180119_1034'),
    ]

    operations = [
        migrations.AlterField(
            model_name='inventory',
            name='end',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Ends'),
        ),
        migrations.AlterField(
            model_name='inventory',
            name='start',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Starts'),
        ),
    ]
