# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-04-30 17:24
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_storages', '0028_auto_20180430_1919'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='incomingalbaran',
            name='code',
        ),
        migrations.RemoveField(
            model_name='incomingalbaran',
            name='code_counter',
        ),
        migrations.RemoveField(
            model_name='outgoingalbaran',
            name='code',
        ),
        migrations.RemoveField(
            model_name='outgoingalbaran',
            name='code_counter',
        ),
        migrations.RemoveField(
            model_name='requeststock',
            name='code',
        ),
        migrations.RemoveField(
            model_name='requeststock',
            name='code_counter',
        ),
    ]
