# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-02-23 17:46
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0013_salesorderdocument_removed'),
        ('codenerix_storages', '0015_auto_20180219_1229'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='inventoryout',
            name='order',
        ),
        migrations.AddField(
            model_name='inventoryout',
            name='albaran',
            field=models.ForeignKey(default=None, on_delete=django.db.models.deletion.PROTECT, related_name='inventorys', to='codenerix_invoicing.SalesAlbaran', verbose_name='Albaran'),
            preserve_default=False,
        ),
    ]
